Working with remote services
============================

The following collection of modules implement common interface for various remote services.

Common interface
----------------

.. automodule:: rpmrh.service.abc
    :members:

Built-in service adapters
-------------------------

The following services are supported in current version of the package.

Koji instance
*************

.. automodule:: rpmrh.service.koji
    :members:

DNF repository
**************

.. automodule:: rpmrh.service.dnf
    :members:

Jenkins instance
****************

.. automodule:: rpmrh.service.jenkins
    :members:
